# -*- coding: utf-8 -*-
# Generated by Django 1.11.13 on 2018-07-23 06:14
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='OnerrorReportInfo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.BooleanField(db_index=True, default=True, help_text='Status', verbose_name='status')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Create Time', verbose_name='created_at')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Update Time', verbose_name='updated_at')),
                ('lineNo', models.IntegerField(default=0, help_text='\u5f02\u5e38\u884c\u53f7', verbose_name='lineNo')),
                ('columnNo', models.IntegerField(default=0, help_text='\u5f02\u5e38\u5217\u53f7', verbose_name='columnNo')),
                ('scriptURI', models.CharField(blank=True, help_text='\u5f02\u5e38\u6587\u4ef6\u8def\u5f84', max_length=255, null=True, verbose_name='scriptURI')),
                ('errorMessage', models.CharField(blank=True, help_text='\u5f02\u5e38\u4fe1\u606f', max_length=255, null=True, verbose_name='errorMessage')),
                ('stack', models.TextField(blank=True, help_text='\u5f02\u5e38\u5806\u6808\u4fe1\u606f', null=True, verbose_name='stack')),
            ],
            options={
                'verbose_name': 'onerrorreportinfo',
                'verbose_name_plural': 'onerrorreportinfo',
            },
        ),
    ]
